<?php
/**
 * Copyright © 2018 Filoblu S.p.A. All rights reserved.
 */

namespace FiloBlu\EvaAttributes\Console\Command;

use Exception;
use FiloBlu\EvaAttributes\Helper\AttributeHelper;
use Magento\Eav\Setup\EavSetupFactory;
use Magento\Framework\App\Area;
use Magento\Framework\App\State;
use Magento\Framework\Setup\ModuleDataSetupInterface;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

class CreateAttributes extends Command
{

    /**
     * @var EavSetupFactory
     */
    private $eavSetupFactory;

    /**
     * @var AttributeHelper
     */
    private $attributeHelper;

    /**
     * @var ModuleDataSetupInterface
     */
    protected $setup;

    /**
     * @var State
     */
    private $state;

    /**
     * CreateAttributes constructor.
     * @param EavSetupFactory $eavSetupFactory
     * @param AttributeHelper $attributeHelper
     * @param State $state
     * @param ModuleDataSetupInterface $setup
     * @param string $name
     */
    public function __construct(
        EavSetupFactory          $eavSetupFactory,
        AttributeHelper          $attributeHelper,
        State                    $state,
        ModuleDataSetupInterface $setup,
                                 $name = null
    ) {
        $this->setup = $setup;
        $this->eavSetupFactory = $eavSetupFactory;
        $this->attributeHelper = $attributeHelper;
        $this->state = $state;
        parent::__construct($name);
    }

    /**
     * {@inheritdoc}
     */
    protected function execute(InputInterface $input, OutputInterface $output)
    {
        //Area Code Fix
        try {
            $this->state->setAreaCode(Area::AREA_GLOBAL);
        } catch (Exception $e) {
            //Area code is already set
        }

        $eavSetup = $this->eavSetupFactory->create(['setup' => $this->setup]);

        $this->attributeHelper->installAttributes($eavSetup);
    }

    /**
     * {@inheritdoc}
     */
    protected function configure()
    {
        $this->setName("eva:attributes:create");
        $this->setDescription("Create Attributes");
    }
}
